@@ -264,10 +264,10 @@ def timeseries(
     report_type
         Can be
 
-        * "hospital_daily_occupancy"
-        * "hospital_weekly_admissions"
-        * "icu_daily_occupancy"
-        * "icu_weekly_admissions"
+        * "hospital_daily"
+        * "hospital_weekly"
+        * "icu_daily"
+        * "icu_weekly"
         * "R"
         * "vaccinations_daily"
         * "vaccinations_people"
@@ -322,19 +322,27 @@ def timeseries(
         df = None
     return df
 
-def hospital_daily_occupancy(
+def hospitalization(
     country: str,
+    report_type: str = 'all',
     start_date: date = None,
     end_date: date = None,
     params: dict = None,
     fill_value=np.nan,
 ) -> pd.DataFrame:
-    """Get daily hospital occupancy as a DataFrame from the db.
+    """Get hospitalization data as a DataFrame from the db.
 
     Parameters
     ----------
     country
         The country name for which to get the timeseries
+    report_type : optional
+        the type of data, if `None`, returns all. Can be
+
+        * None (default)
+        * "hospital_daily"
+        * "hospital_weekly"
+
     start_date : optional
         The date at which the timeseries will start
     end_date : optional
@@ -355,30 +363,62 @@ def hospital_daily_occupancy(
     Returns
     -------
     df
-        A DataFrame consisting of the columns "date" and "hospital_daily_occupancy"
+        A DataFrame consisting of the columns "date" and the report types
     """
-    return timeseries(
-        country,
-        'hospital_daily',
-        start_date,
-        end_date,
-        params,
-        fill_value,
-    )
+    valid_types = ('hospital_daily', 'hospital_weekly')
+    if report_type is not None and report_type not in valid_types:
+        raise ValueError(f'report_type can only be one of {valid_types}')
+    df = None
+    if report_type is None:
+        df = timeseries(
+            country,
+            'hospital_daily',
+            start_date,
+            end_date,
+            params,
+            fill_value,
+        )
+        df_weekly = timeseries(
+            country,
+            'hospital_weekly',
+            start_date,
+            end_date,
+            params,
+            fill_value,
+        )
+        df['hospital_weekly'] = df_weekly['hospital_weekly']
+    else:
+        df = timeseries(
+            country,
+            report_type,
+            start_date,
+            end_date,
+            params,
+            fill_value,
+        )
+    return df
 
-def hospital_weekly_admissions(
+def icu(
     country: str,
+    report_type: str = 'all',
     start_date: date = None,
     end_date: date = None,
     params: dict = None,
     fill_value=np.nan,
 ) -> pd.DataFrame:
-    """Get weekly hospital admissions as a DataFrame from the db.
+    """Get ICU data as a DataFrame from the db.
 
     Parameters
     ----------
     country
         The country name for which to get the timeseries
+    report_type : optional
+        the type of data, if `None`, returns all. Can be
+
+        * None (default)
+        * "icu_daily"
+        * "icu_weekly"
+
     start_date : optional
         The date at which the timeseries will start
     end_date : optional
@@ -399,104 +439,40 @@ def hospital_weekly_admissions(
     Returns
     -------
     df
-        A DataFrame consisting of the columns "date" and "hospital_weekly_admissions"
+        A DataFrame consisting of the columns "date" and the report types
     """
-    return timeseries(
-        country,
-        'hospital_weekly',
-        start_date,
-        end_date,
-        params,
-        fill_value,
-    )
-
-def icu_daily_occupancy(
-    country: str,
-    start_date: date = None,
-    end_date: date = None,
-    params: dict = None,
-    fill_value=np.nan,
-) -> pd.DataFrame:
-    """Get daily ICU occupancy as a DataFrame from the db.
-
-    Parameters
-    ----------
-    country
-        The country name for which to get the timeseries
-    start_date : optional
-        The date at which the timeseries will start
-    end_date : optional
-        The date at which the timeseries will end
-    params : optional
-        optional query parameters
-
-        * "source_name"
-
-    fill_value : optional
-        decide what to do with missing values, can be
-
-        * np.nan: fill with NaNs, to optain regular timeseries
-        * a number: fill with constant value, e.g. 0
-        * 'drop': drop missing values
-        * 'interpolate' : linear interpolation over gaps
-
-    Returns
-    -------
-    df
-        A DataFrame consisting of the columns "date" and "icu_daily_occupancy"
-    """
-    return timeseries(
-        country,
-        'icu_daily',
-        start_date,
-        end_date,
-        params,
-        fill_value,
-    )
-
-def icu_weekly_admissions(
-    country: str,
-    start_date: date = None,
-    end_date: date = None,
-    params: dict = None,
-    fill_value=np.nan,
-) -> pd.DataFrame:
-    """Get weekly ICU admissions as a DataFrame from the db.
-
-    Parameters
-    ----------
-    country
-        The country name for which to get the timeseries
-    start_date : optional
-        The date at which the timeseries will start
-    end_date : optional
-        The date at which the timeseries will end
-    params : optional
-        optional query parameters
-
-        * "source_name"
-
-    fill_value : optional
-        decide what to do with missing values, can be
-
-        * np.nan: fill with NaNs, to optain regular timeseries
-        * a number: fill with constant value, e.g. 0
-        * 'drop': drop missing values
-        * 'interpolate' : linear interpolation over gaps
-
-    Returns
-    -------
-    df
-        A DataFrame consisting of the columns "date" and "icu_weekly_admissions"
-    """
-    return timeseries(
-        country,
-        'icu_weekly',
-        start_date,
-        end_date,
-        params,
-        fill_value,
-    )
+    valid_types = ('icu_daily', 'icu_weekly')
+    if report_type is not None and report_type not in valid_types:
+        raise ValueError(f'report_type can only be one of {valid_types}')
+    df = None
+    if report_type is None:
+        df = timeseries(
+            country,
+            'icu_daily',
+            start_date,
+            end_date,
+            params,
+            fill_value,
+        )
+        df_weekly = timeseries(
+            country,
+            'icu_weekly',
+            start_date,
+            end_date,
+            params,
+            fill_value,
+        )
+        df['icu_weekly'] = df_weekly['icu_weekly']
+    else:
+        df = timeseries(
+            country,
+            report_type,
+            start_date,
+            end_date,
+            params,
+            fill_value,
+        )
+    return df
 
 def R(
     country: str,
@@ -542,8 +518,9 @@ def R(
         fill_value,
     )
 
-def vaccinations_daily(
+def vaccinations(
     country: str,
+    report_type: str = None,
     start_date: date = None,
     end_date: date = None,
     params: dict = None,
@@ -555,6 +532,16 @@ def vaccinations_daily(
     ----------
     country
         The country name for which to get the timeseries
+    report_type : optional
+        the type of data, if `None`, returns all. Can be
+
+        * None (default)
+        * "vaccinations_daily"
+        * "vaccinations_people"
+        * "vaccinations_people_fully"
+        * "vaccinations_total"
+        * "vaccinations_total_booster"
+
     start_date : optional
         The date at which the timeseries will start
     end_date : optional
@@ -577,190 +564,45 @@ def vaccinations_daily(
     df
         A DataFrame consisting of the columns "date" and "vaccinations_daily"
     """
-    return timeseries(
-        country,
+    valid_types = (
         'vaccinations_daily',
-        start_date,
-        end_date,
-        params,
-        fill_value,
-    )
-
-def vaccinations_people(
-    country: str,
-    start_date: date = None,
-    end_date: date = None,
-    params: dict = None,
-    fill_value=np.nan,
-) -> pd.DataFrame:
-    """Get vaccinated people as a DataFrame from the db.
-
-    Parameters
-    ----------
-    country
-        The country name for which to get the timeseries
-    start_date : optional
-        The date at which the timeseries will start
-    end_date : optional
-        The date at which the timeseries will end
-    params : optional
-        optional query parameters
-
-        * "source_name"
-
-    fill_value : optional
-        decide what to do with missing values, can be
-
-        * np.nan: fill with NaNs, to optain regular timeseries
-        * a number: fill with constant value, e.g. 0
-        * 'drop': drop missing values
-        * 'interpolate' : linear interpolation over gaps
-
-    Returns
-    -------
-    df
-        A DataFrame consisting of the columns "date" and "vaccinations_people"
-    """
-    return timeseries(
-        country,
         'vaccinations_people',
-        start_date,
-        end_date,
-        params,
-        fill_value,
-    )
-
-def vaccinations_people_fully(
-    country: str,
-    start_date: date = None,
-    end_date: date = None,
-    params: dict = None,
-    fill_value=np.nan,
-) -> pd.DataFrame:
-    """Get fully vaccinated people as a DataFrame from the db.
-
-    Parameters
-    ----------
-    country
-        The country name for which to get the timeseries
-    start_date : optional
-        The date at which the timeseries will start
-    end_date : optional
-        The date at which the timeseries will end
-    params : optional
-        optional query parameters
-
-        * "source_name"
-
-    fill_value : optional
-        decide what to do with missing values, can be
-
-        * np.nan: fill with NaNs, to optain regular timeseries
-        * a number: fill with constant value, e.g. 0
-        * 'drop': drop missing values
-        * 'interpolate' : linear interpolation over gaps
-
-    Returns
-    -------
-    df
-        A DataFrame consisting of the columns "date" and "vaccinations_people_fully"
-    """
-    return timeseries(
-        country,
         'vaccinations_people_fully',
-        start_date,
-        end_date,
-        params,
-        fill_value,
-    )
-
-def vaccinations_total(
-    country: str,
-    start_date: date = None,
-    end_date: date = None,
-    params: dict = None,
-    fill_value=np.nan,
-) -> pd.DataFrame:
-    """Get total vaccinations as a DataFrame from the db.
-
-    Parameters
-    ----------
-    country
-        The country name for which to get the timeseries
-    start_date : optional
-        The date at which the timeseries will start
-    end_date : optional
-        The date at which the timeseries will end
-    params : optional
-        optional query parameters
-
-        * "source_name"
-
-    fill_value : optional
-        decide what to do with missing values, can be
-
-        * np.nan: fill with NaNs, to optain regular timeseries
-        * a number: fill with constant value, e.g. 0
-        * 'drop': drop missing values
-        * 'interpolate' : linear interpolation over gaps
-
-    Returns
-    -------
-    df
-        A DataFrame consisting of the columns "date" and "vaccinations_total"
-    """
-    return timeseries(
-        country,
         'vaccinations_total',
-        start_date,
-        end_date,
-        params,
-        fill_value,
-    )
-
-def vaccinations_total_booster(
-    country: str,
-    start_date: date = None,
-    end_date: date = None,
-    params: dict = None,
-    fill_value=np.nan,
-) -> pd.DataFrame:
-    """Get total vaccination booster as a DataFrame from the db.
-
-    Parameters
-    ----------
-    country
-        The country name for which to get the timeseries
-    start_date : optional
-        The date at which the timeseries will start
-    end_date : optional
-        The date at which the timeseries will end
-    params : optional
-        optional query parameters
-
-        * "source_name"
-
-    fill_value : optional
-        decide what to do with missing values, can be
-
-        * np.nan: fill with NaNs, to optain regular timeseries
-        * a number: fill with constant value, e.g. 0
-        * 'drop': drop missing values
-        * 'interpolate' : linear interpolation over gaps
-
-    Returns
-    -------
-    df
-        A DataFrame consisting of the columns "date" and "vaccinations_total_booster"
-    """
-    return timeseries(
-        country,
         'vaccinations_total_booster',
-        start_date,
-        end_date,
-        params,
-        fill_value,
     )
+    if report_type is not None and report_type not in valid_types:
+        raise ValueError(f'report_type can only be one of {valid_types}')
+    df = None
+    if report_type is None:
+        df = timeseries(
+            country,
+            valid_types[1],
+            start_date,
+            end_date,
+            params,
+            fill_value,
+        )
+        for r in valid_types[1:]:
+            df_app = timeseries(
+                country,
+                r,
+                start_date,
+                end_date,
+                params,
+                fill_value,
+            )
+            df[r] = df_app[r]
+    else:
+        df = timeseries(
+            country,
+            report_type,
+            start_date,
+            end_date,
+            params,
+            fill_value,
+        )
+    return df
 
 def npi(
     country: str,
@@ -845,7 +687,7 @@ def npi(
 
 def npis(
     country: str,
-    npi_types: Union[list, str],
+    npi_types: Union[list, str] = None,
     start_date: date = None,
     end_date: date = None,
     params: dict = None,
@@ -857,9 +699,10 @@ def npis(
     ----------
     country
         The country name for which to get the reports
-    npi_types
-        choose the npi types from
+    npi_types : optional
+        the npi types, if `None`, returns all. Can be
 
+        * None (default)
         * "stringency"
         * "school closing"
         * "workplace closing"
@@ -901,7 +744,7 @@ def npis(
         A DataFrame consisting of the columns "date" and `npi_type`
     """
     _npi_types = npi_types
-    if npi_types == 'all':
+    if npi_types is None:
         _npi_types = [
             'stringency',
             'school closing',
